import { useEffect } from 'react';
import { useSelector } from 'react-redux';
import dayjs from 'dayjs';

let theGeofence;
export default (keyword, filter, filterSort, filterMap, positions, setFilteredDevices, setFilteredPositions) => {
  const groups = useSelector((state) => state.groups.items);
  const devices = useSelector((state) => state.devices.items);
  const geofences = useSelector((state) => state.geofences.items);
  const geofenceCoordinates = extractCoordinates(geofences);

  function extractCoordinates(geofences){
    var result=[];
    theGeofence = Object.values(geofences)[0];
    if(theGeofence != undefined){
      let coordinatesArr = theGeofence.area.replaceAll("POLYGON","").replaceAll("((","").replaceAll("))","").trim().split(",")
      for(var i=0;i<coordinatesArr.length;i++){
        var ithPt = coordinatesArr[i].trim();
        var ptArr = ithPt.split(" ")
        result.push([parseFloat(ptArr[1].trim()),parseFloat(ptArr[0].trim())]);
      }
    }

    return result;
  }

  function isInsidePolygon(point, vs) {
    
    var x = point[0], y = point[1];
    
    var inside = false;
    for (var i = 0, j = vs.length - 1; i < vs.length; j = i++) {
        var xi = vs[i][0], yi = vs[i][1];
        var xj = vs[j][0], yj = vs[j][1];
        
        var intersect = ((yi > y) != (yj > y))
            && (x < (xj - xi) * (y - yi) / (yj - yi) + xi);
        if (intersect) inside = !inside;
    }
    
    return inside;
};

  useEffect(() => {
    const deviceGroups = (device) => {
      const groupIds = [];
      let { groupId } = device;
      while (groupId) {
        groupIds.push(groupId);
        groupId = groups[groupId]?.groupId || 0;
      }

      return groupIds;
    };


    const filtered = Object.values(devices)
      .filter((device) => !filter.statuses.length || filter.statuses.includes(device.status))
      .filter((device) => !filter.groups.length || deviceGroups(device).some((id) => filter.groups.includes(id)))
      .filter((device) => positions.hasOwnProperty(device.id) && isInsidePolygon([positions[device.id].longitude, positions[device.id].latitude], geofenceCoordinates))
      .filter((device) => {
        const lowerCaseKeyword = keyword.toLowerCase();
        return [device.name, device.uniqueId, device.phone, device.model, device.contact].some((s) => s && s.toLowerCase().includes(lowerCaseKeyword));
      });
    switch (filterSort) {
      case 'name':
        filtered.sort((device1, device2) => device1.name.localeCompare(device2.name));
        break;
      case 'lastUpdate':
        filtered.sort((device1, device2) => {
          const time1 = device1.lastUpdate ? dayjs(device1.lastUpdate).valueOf() : 0;
          const time2 = device2.lastUpdate ? dayjs(device2.lastUpdate).valueOf() : 0;
          return time2 - time1;
        });
        break;
      default:
        break;
    }
    console.log("Devices Positions:");
    console.log(positions);
    console.log("Groups:");
    console.log(groups);
    console.log("Filtered:");
    console.log(filter.groups);
    setFilteredDevices(filtered);

    let geofenceGroupFilter = ""
    for(var i=0;i<filter.groups.length;i++){
      var ithFilter = filter.groups[i]
      if(groups.hasOwnProperty(ithFilter))
        geofenceGroupFilter += (groups[ithFilter]?.name || "")+", ";
    }
    geofenceGroupFilter=geofenceGroupFilter.replace(/,\s*$/, "");
    
    if(document.getElementById('geofenceGroupFilter')!==null)
      document.getElementById('geofenceGroupFilter').innerHTML = geofenceGroupFilter;

    setFilteredPositions(filterMap
      ? filtered.map((device) => positions[device.id]).filter(Boolean)
      : Object.values(positions));
  }, [keyword, filter, filterSort, filterMap, groups, devices, positions, setFilteredDevices, setFilteredPositions]);
};
