import React, { useState,useEffect, useCallback } from 'react';
import { useDispatch } from 'react-redux';
import {
  Divider, Typography, IconButton, Toolbar,
  Paper,
} from '@mui/material';
import Tooltip from '@mui/material/Tooltip';
import makeStyles from '@mui/styles/makeStyles';
import ArrowBackIcon from '@mui/icons-material/ArrowBack';
import UploadFileIcon from '@mui/icons-material/UploadFile';
import { useNavigate } from 'react-router-dom';
import MapView from '../map/core/MapView';
import MapCurrentLocation from '../map/MapCurrentLocation';
import MapGeofenceEdit from '../map/draw/MapGeofenceEdit';
import GeofencesList from './GeofencesList';
import { useTranslation } from '../common/components/LocalizationProvider';
import MapGeocoder from '../map/geocoder/MapGeocoder';
import { errorsActions } from '../store';
import MapScale from '../map/MapScale';
import {useLocation} from 'react-router-dom';
import { map } from '../map/core/MapView';
import {
  Button, Dialog, DialogActions, DialogContent,TextField
} from '@mui/material';
import maplibregl from 'maplibre-gl';
import { fontSize } from '../map/core/mapUtil';

const useStyles = makeStyles((theme) => ({
  details: {
    display: 'flex',
    flexDirection: 'column',
    gap: theme.spacing(2),
    paddingBottom: theme.spacing(1),
    paddingTop: theme.spacing(3),
  },
  root: {
    height: '100%',
    display: 'flex',
    flexDirection: 'column',
  },
  content: {
    flexGrow: 1,
    overflow: 'hidden',
    display: 'flex',
    flexDirection: 'row',
    [theme.breakpoints.down('sm')]: {
      flexDirection: 'column-reverse',
    },
  },
  drawer: {
    display: 'flex',
    flexDirection: 'column',
    [theme.breakpoints.up('sm')]: {
      width: theme.dimensions.drawerWidthDesktop,
    },
    [theme.breakpoints.down('sm')]: {
      height: theme.dimensions.drawerHeightPhone,
    },
  },
  mapContainer: {
    flexGrow: 1,
  },
  title: {
    flexGrow: 1,
  },
  fileInput: {
    display: 'none',
  },
  savePickUpPointBtn: {
    fontSize: '1rem',
    position: 'absolute',
    bottom: '20px',
    zIndex: '2',
    right: '20px',
    color: 'white',
    backgroundColor: '#795695',
    borderRadius: '0.5rem',
    padding: '0.5rem',
  },
  addingBoundingBoxNotes: {
    fontSize: '1.5rem',
    position: 'absolute',
    bottom: '20px',
    zIndex: '2',
    right: '20px',
    color: 'white',
    backgroundColor: '#795695',
    borderRadius: '0.5rem',
    padding: '0.5rem',
  }
}));


let image=null, clickedPickUpPointLngLat=null,editPickUpPoints=null;

const GeofencesPage = () => {
  const location = useLocation();
  const classes = useStyles();
  const dispatch = useDispatch();
  const navigate = useNavigate();
  const t = useTranslation();
  const [addDialogShown, setAddDialogShown] = useState(false);

  const [selectedGeofenceId, setSelectedGeofenceId] = useState();
  const [pickUpPointName, setPickUpPointName] = useState();
  const [degreeBearing, setDegreeBearing] = useState();

  const handleFile = (event) => {
    const files = Array.from(event.target.files);
    const [file] = files;
    const reader = new FileReader();
    reader.onload = async () => {
      const xml = new DOMParser().parseFromString(reader.result, 'text/xml');
      const segment = xml.getElementsByTagName('trkseg')[0];
      const coordinates = Array.from(segment.getElementsByTagName('trkpt'))
        .map((point) => `${point.getAttribute('lat')} ${point.getAttribute('lon')}`)
        .join(', ');
      const area = `LINESTRING (${coordinates})`;
      const newItem = { name: t('sharedGeofence'), area };
      try {
        const response = await fetch('/api/geofences', {
          method: 'POST',
          headers: { 'Content-Type': 'application/json' },
          body: JSON.stringify(newItem),
        });
        if (response.ok) {
          const item = await response.json();
          navigate(`/settings/geofence/${item.id}`);
        } else {
          throw Error(await response.text());
        }
        

      } catch (error) {
        dispatch(errorsActions.push(error.message));
      }
    };
    reader.onerror = (event) => {
      dispatch(errorsActions.push(event.target.error));
    };
    reader.readAsText(file);
  };

  const handleAddClick = async(e) =>{  
    if(image==null)
      image = await map.loadImage('/target.png');
    console.log(e.lngLat.toArray());
    clickedPickUpPointLngLat = e.lngLat.toArray();
    setPickUpPointName('');
    setAddDialogShown(true);
  };

  const onBearingResult = () =>{
    navigate("../settings/geofence/"+selectedGeofenceId.toString(),{ state: {
      geofenceId: selectedGeofenceId,
      mode:location.state.mode,
      value:degreeBearing
    }});
  }

  const onResult = () =>{

    let ppName = pickUpPointName;
    map.addImage(ppName, image.data);

      map.addSource(ppName+'point', {
          'type': 'geojson',
          'data': {
              'type': 'FeatureCollection',
              'features': [
                  {
                      'type': 'Feature',
                      'geometry': {
                          'type': 'Point',
                          'coordinates': clickedPickUpPointLngLat
                      }
                  }
              ]
          }
      });
    
        map.addLayer({
            'id': ppName+'Layer',
            'type': 'symbol',
            'source': ppName+'point',
            'layout': {
                'icon-image': ppName,
                'icon-size': 1.0
            }
        });
        setAddDialogShown(false);

       if(window.hasItemWithKeyAndValue(editPickUpPoints,"name",pickUpPointName)){
        alert("Do you want to replace existing point?")
       }else{
          editPickUpPoints.push({name:ppName, coordinate:clickedPickUpPointLngLat[1].toString()+","+clickedPickUpPointLngLat[0].toString()});
       }
  }

  const savePickUpPoints = () =>{

    console.log(editPickUpPoints);
    
    navigate("../settings/geofence/"+selectedGeofenceId.toString(),{ state: {
      geofenceId: selectedGeofenceId,
      mode:location.state.mode,
      value:JSON.stringify(editPickUpPoints)
    }});
  }

  const onDegreeBearingChange = (val) =>{
    console.log(val);
    map.rotateTo(parseFloat(val));
    setDegreeBearing(parseFloat(val));
  }


  useEffect(() => {
      if(location.state){

        if(location.state.mode=='selectPickUpPoints'){
          map.on('click', handleAddClick);
          let str = location.state.pickUpPoints || "";
          editPickUpPoints = (JSON.parse(str.trim()==="" ? "[]" : str));
        }

        setSelectedGeofenceId(location.state.geofenceId);
      }
    }, []);


  return (
    <div className={classes.root}>
      <div className={classes.content}>
        <Paper square className={classes.drawer}>
          <Toolbar>
            <IconButton edge="start" sx={{ mr: 2 }} onClick={() => navigate(-1)}>
              <ArrowBackIcon />
            </IconButton>
            <Typography variant="h6" className={classes.title}>{t('sharedGeofences')}</Typography>
            <label htmlFor="upload-gpx">
              <input accept=".gpx" id="upload-gpx" type="file" className={classes.fileInput} onChange={handleFile} />
              <IconButton edge="end" component="span" onClick={() => {}}>
                <Tooltip title={t('sharedUpload')}>
                  <UploadFileIcon />
                </Tooltip>
              </IconButton>
            </label>
          </Toolbar>
          <Divider />
          <GeofencesList onGeofenceSelected={setSelectedGeofenceId} />
        </Paper>
        <div className={classes.mapContainer}>
          <MapView pageMode={location.state==null?"":location.state.mode}>
            <MapGeofenceEdit selectedGeofenceId={selectedGeofenceId} pageMode={location.state==null?"":location.state.mode} />
          </MapView>
          <MapScale />
          <MapCurrentLocation />
          <MapGeocoder />

          {location.state && location.state.mode=='selectPickUpPoints' &&
            <div><button id="savePickUpBtn" className={classes.savePickUpPointBtn} onClick={() => savePickUpPoints()}>SAVE NEW PICK UP POINTS</button></div>
          }

          {location.state && location.state.mode=='addingBoundingBox' &&
            <div className={classes.addingBoundingBoxNotes}>Use polygon tool to draw a bounding box of premise's perimeter and press ENTER button to confirm.</div>
          }

          {location.state && location.state.mode=='addingBearing' &&
            <div className={classes.addingBoundingBoxNotes}>
            <TextField  label="degreeBearing" value={degreeBearing||'0'}  onChange={(e) => onDegreeBearingChange(e.target.value)}/>
            <Button
                color="primary"
                onClick={() => onBearingResult()}
              >ADD</Button>
            Adjust degree bearing input to desired orientation and click on ADD button to confirm.</div>
          }

          {location.state && 
          <Dialog open={addDialogShown} fullWidth maxWidth="xs">
            <DialogContent className={classes.details}>
                <TextField  label="pickUpPointName"  onChange={(e) => setPickUpPointName(e.target.value)}/>
            </DialogContent>
            <DialogActions>
              <Button
                color="primary"
                onClick={() => onResult()}
              >
                {t('sharedAdd')}
              </Button>
              <Button
                autoFocus
                onClick={() => {setAddDialogShown(false)}}
              >
                {t('sharedCancel')}
              </Button>
            </DialogActions>
          </Dialog>
          }
          
        </div>
      </div>
    </div>
  );
};

export default GeofencesPage;
